==> motion_toast-2.1.7.tar.gz: lib/widgets/motion_toast_background.dart <==
import 'package:flutter/material.dart';
import 'package:motion_toast/resources/arrays.dart';

/// Widget that renders a motion toast background
class MotionToastBackground extends StatelessWidget {
  /// Border radius of the background.
  final double borderRadius;

  /// The color of the background.
  final Color backgroundColor;

  /// Widget to render on top of the background.
  final Widget child;

  /// Appearance type of the background.
  final BACKGROUND_TYPE backgroundType;

  /// Creates a widget that renders the child
  /// on top of customizable background.
  const MotionToastBackground({
    Key? key,
    required this.borderRadius,
    required this.backgroundColor,
    required this.child,
    required this.backgroundType,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    if (backgroundType == BACKGROUND_TYPE.lighter) {
      return Stack(
        children: <Widget>[
          Container(
            decoration: BoxDecoration(
              color: Colors.white,
              borderRadius: BorderRadius.all(
                Radius.circular(borderRadius),
              ),
            ),
          ),
          _renderWidgetChild(
            opacity: 0.4,
          )
        ],
      );
    }
    return _renderWidgetChild();
  }

  Widget _renderWidgetChild({double opacity = 0.8}) {
    return Container(
      decoration: BoxDecoration(
        color: backgroundType == BACKGROUND_TYPE.solid
            ? backgroundColor
            : backgroundColor.withOpacity(opacity),
        borderRadius: BorderRadius.all(
          Radius.circular(borderRadius),
        ),
      ),
      child: child,
    );
  }
}

==> motion_toast-2.1.9.tar.gz: lib/widgets/motion_toast_background.dart <==
import 'package:flutter/material.dart';
import 'package:motion_toast/resources/arrays.dart';

/// Widget that renders a motion toast background
class MotionToastBackground extends StatelessWidget {
  /// Border radius of the background.
  final double borderRadius;

  /// The color of the background.
  final Color backgroundColor;

  /// Widget to render on top of the background.
  final Widget child;

  /// Appearance type of the background.
  final BackgroundType backgroundType;

  /// Creates a widget that renders the child
  /// on top of customizable background.
  const MotionToastBackground({
    Key? key,
    required this.borderRadius,
    required this.backgroundColor,
    required this.child,
    required this.backgroundType,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    if (backgroundType == BackgroundType.lighter) {
      return Stack(
        children: <Widget>[
          Container(
            decoration: BoxDecoration(
              color: Colors.white,
              borderRadius: BorderRadius.all(
                Radius.circular(borderRadius),
              ),
            ),
          ),
          _renderWidgetChild(
            opacity: 0.4,
          )
        ],
      );
    }
    return _renderWidgetChild();
  }

  Widget _renderWidgetChild({double opacity = 0.8}) {
    return Container(
      decoration: BoxDecoration(
        color: backgroundType == BackgroundType.solid
            ? backgroundColor
            : backgroundColor.withOpacity(opacity),
        borderRadius: BorderRadius.all(
          Radius.circular(borderRadius),
        ),
      ),
      child: child,
    );
  }
}
